import pandas as pd
from bs4 import BeautifulSoup


class DataFrameModifier:
    def __init__(self):
        df = pd.read_csv("student_mental_health.csv")
        df['Mental health'] = df['Depression'] + df['Anxiety'] + df[
            'Panic attack']
        self.__df = df.dropna().reset_index(drop=True)

    @property
    def normal(self):
        return self.__df

    @property
    def text(self):
        df = self.__df.copy()

        def map_binary_column(data, col_name, name):
            data[col_name] = data[col_name].apply(
                lambda x: 'have ' + name if x == 1 else 'don\'t have ' + name)
            return data

        df = map_binary_column(df, 'Marital Status', 'marital')
        df = map_binary_column(df, 'Depression', 'depression')
        df = map_binary_column(df, 'Anxiety', 'anxiety')
        df = map_binary_column(df, 'Panic attack', 'panic')
        df = map_binary_column(df, 'Treatment', 'treatment')

        mapping = {
            0: "Find",
            1: "Normal",
            2: "Issue",
            3: "Risk"
        }
        df["Mental health"] = df["Mental health"].map(mapping)

        return df

    @property
    def noText(self):
        df = self.__df.copy()
        cgpa_mapping = {
            "0 - 1.99": 0.995,
            "2.00 - 2.49": 2.245,
            "2.50 - 2.99": 2.745,
            "3.00 - 3.49": 3.245,
            "3.50 - 4.00": 3.745
        }
        df["CGPA"] = df["CGPA"].map(cgpa_mapping)

        df["Year of study"] = df["Year of study"].str.extract(r'(\d+)')
        df["Year of study"] = df["Year of study"].astype(int)

        return df

    def counts(self, x_data):
        df = self.text
        return df[x_data].value_counts()


class HTMLReader:
    def __init__(self):
        with open("details.html") as file:
            soup = BeautifulSoup(file, "html.parser")
            self.__body_text = ''.join(
                [str(x) for x in soup.body.contents if hasattr(x, 'text')])

    def getBody(self):
        return self.__body_text
